#define DACT_VER_MAJOR 0
#define DACT_VER_MINOR 3
#define DACT_VER_REVISION 10

#ifndef DACT_BLK_SIZE
#define DACT_BLK_SIZE 1024
#endif


#define DACT_MODE_COMPR 1
#define DACT_MODE_DECMP 2

#ifndef TWO_BYTES
#if defined(__WIN32__) || defined(GO32)
#undef USE_ZLIB
#define TWO_BYTES unsigned int
#else
#define TWO_BYTES unsigned short
#endif defined(__WIN32__) || defined(GO32)
#endif !defined(TWO_BYTES)


struct dact_header {
	TWO_BYTES	size;
	unsigned char	algo;
};
